@@ -3,14 +3,32 @@ import math
 import traceback
 
 from django import http
+from django.contrib.auth import get_user_model
+from django.contrib.auth.models import Permission
+from django.contrib.contenttypes.models import ContentType
 
 from . import version
 
-MAKE_PUBLIC_CODENAME = "make_view_public"
+PUBLIC_PERM = "make_view_public"
+SHARE_PERM = "share_view"
 
 
-def can_make_public(user):
-    return user.has_perm(f"data_browser.{MAKE_PUBLIC_CODENAME}")
+def has_permission(user, permission):
+    return user.has_perm(f"data_browser.{permission}")
+
+
+def users_with_permission(permission):
+    from .models import View
+
+    ct = ContentType.objects.get_for_model(View)
+    perm = Permission.objects.get(codename=permission, content_type=ct)
+    return get_user_model().objects.with_perm(perm)
+
+
+def str_user(user):
+    return (
+        str(user) or user.get_username() or getattr(user, user.get_email_field_name())
+    )
 
 
 def JsonResponse(data):
@@ -76,6 +94,14 @@ def get_optimal_decimal_places(nums, sf=3, max_dp=6):
     return max(0, min(dp_for_sf, max_actual_dp, max_dp))
 
 
+def add_request_info(request, *, view=False):
+    request.data_browser = {
+        "public_view": view,
+        "fields": set(),
+        "calculated_fields": set(),
+    }
+
+
 class Settings:
     _defaults = {
         "DATA_BROWSER_ALLOW_PUBLIC": False,
@@ -86,6 +112,7 @@ class Settings:
         "DATA_BROWSER_ADMIN_FIELD_NAME": "admin",
         "DATA_BROWSER_USING_DB": "default",
         "DATA_BROWSER_ADMIN_OPTIONS": {},
+        "DATA_BROWSER_APPS_EXPANDED": True,
     }
 
     def __getattr__(self, name):
