@@ -5,7 +5,7 @@ from django.db import models
 from django.urls import reverse
 from django.utils import crypto, timezone
 
-from .common import MAKE_PUBLIC_CODENAME, settings
+from .common import PUBLIC_PERM, SHARE_PERM, settings
 
 global_data = threading.local()
 
@@ -17,7 +17,8 @@ def get_id():
 class View(models.Model):
     class Meta:
         permissions = [
-            (MAKE_PUBLIC_CODENAME, "Can make a saved view publicly available")
+            (PUBLIC_PERM, "Can make a saved view publicly available"),
+            (SHARE_PERM, "Can share a saved view with other users"),
         ]
 
     id = models.CharField(primary_key=True, max_length=12, default=get_id)
@@ -25,6 +26,7 @@ class View(models.Model):
 
     name = models.CharField(max_length=64, blank=False)
     description = models.TextField(blank=True)
+    folder = models.CharField(max_length=64, blank=True)
     owner = models.ForeignKey(
         settings.AUTH_USER_MODEL, null=True, blank=True, on_delete=models.SET_NULL
     )
@@ -33,7 +35,7 @@ class View(models.Model):
     public_slug = models.CharField(max_length=12, default=get_id, blank=False)
     shared = models.BooleanField(default=False)
 
-    model_name = models.CharField(max_length=32, blank=False)
+    model_name = models.CharField(max_length=64, blank=False)
     fields = models.TextField(blank=True)
     query = models.TextField(blank=True)
     limit = models.IntegerField(blank=False, null=False, default=1000)
