@@ -5,6 +5,7 @@ import json
 import marshal
 import pstats
 import sys
+from collections import defaultdict
 
 import django.contrib.admin.views.decorators as admin_decorators
 import hyperlink
@@ -19,7 +20,15 @@ from django.utils import timezone
 from django.views.decorators import csrf
 
 from . import version
-from .common import HttpResponse, JsonResponse, can_make_public, settings
+from .common import (
+    PUBLIC_PERM,
+    SHARE_PERM,
+    HttpResponse,
+    JsonResponse,
+    add_request_info,
+    has_permission,
+    settings,
+)
 from .format_csv import get_csv_rows
 from .models import View
 from .orm_admin import get_models
@@ -129,30 +138,32 @@ def _get_config(request):
         for model_name in orm_models
     }
 
+    model_names_by_app = defaultdict(set)
+    for name, model in orm_models.items():
+        if model.root:
+            # todo why don't we get this in parts and then assemble it
+            app_name, model_name = name.split(".")
+            model_names_by_app[app_name].add(model_name)
+
     return {
         "baseUrl": reverse("data_browser:home"),
         "types": types,
         "allModelFields": all_model_fields,
-        "sortedModels": sorted(
-            name for name, model in orm_models.items() if model.root
-        ),
-        "canMakePublic": can_make_public(request.user),
+        "sortedModels": [
+            {"appName": app_name, "modelNames": sorted(model_names)}
+            for app_name, model_names in sorted(model_names_by_app.items())
+        ],
+        "canMakePublic": has_permission(request.user, PUBLIC_PERM),
+        "canShare": has_permission(request.user, SHARE_PERM),
         "sentryDsn": settings.DATA_BROWSER_FE_DSN,
         "defaultRowLimit": settings.DATA_BROWSER_DEFAULT_ROW_LIMIT,
-    }
-
-
-def _add_request_info(request, *, view=False):
-    request.data_browser = {
-        "public_view": view,
-        "fields": set(),
-        "calculated_fields": set(),
+        "appsExpanded": settings.DATA_BROWSER_APPS_EXPANDED,
     }
 
 
 @admin_decorators.staff_member_required
 def query_ctx(request, *, model_name="", fields=""):
-    _add_request_info(request)
+    add_request_info(request)
     config = _get_config(request)
     return JsonResponse(config)
 
@@ -173,7 +184,8 @@ def admin_action(request, model_name, fields):
         raise http.Http404(f"'{query.model_name}' does not exist")  # pragma: no cover
 
     bound_query = BoundQuery.bind(query, orm_models)
-    bound_field = bound_query.fields[0].orm_bound_field
+    idx = [field.path_str for field in bound_query.fields].index(field)
+    bound_field = bound_query.fields[idx].orm_bound_field
 
     if not bound_field.field.actions or action not in bound_field.field.actions:
         raise http.Http404(f"bad action '{action}'")  # pragma: no cover
@@ -191,7 +203,7 @@ def admin_action(request, model_name, fields):
 @csrf.ensure_csrf_cookie
 @admin_decorators.staff_member_required
 def query_html(request, *, model_name="", fields=""):
-    _add_request_info(request)
+    add_request_info(request)
 
     if request.method == "POST":
         return admin_action(request, model_name, fields)
@@ -217,7 +229,7 @@ def query_html(request, *, model_name="", fields=""):
 
 @admin_decorators.staff_member_required
 def query(request, *, model_name, fields="", media):
-    _add_request_info(request)
+    add_request_info(request)
 
     params = hyperlink.parse(request.get_full_path()).query
 
@@ -266,14 +278,14 @@ def query(request, *, model_name, fields="", media):
 
 
 def view(request, pk, media):
-    _add_request_info(request, view=True)
+    add_request_info(request, view=True)
 
     view = get_object_or_404(View.objects.filter(public=True), public_slug=pk)
     if (
         # some of these are checked by the admin but this is a good time to be paranoid
         view.owner.is_active
         and view.owner.is_staff
-        and can_make_public(view.owner)
+        and has_permission(view.owner, PUBLIC_PERM)
         and settings.DATA_BROWSER_ALLOW_PUBLIC
     ):
         request.user = view.owner  # public views are run as the person who owns them
@@ -294,7 +306,7 @@ def _data_response(request, query, media, privileged=False, strict=False):
         raise http.Http404(f"{query.model_name} does not exist")
     bound_query = BoundQuery.bind(query, orm_models)
 
-    if strict and not all(f.is_valid for f in bound_query.filters):
+    if strict and not bound_query.all_valid():
         return http.HttpResponseBadRequest()
 
     if media == "csv":
