@@ -1,7 +1,10 @@
 import React, { useState, useEffect, useRef, useContext } from "react";
 import { Redirect } from "react-router-dom";
-import "./App.scss";
+
 import { ShowTooltip, HideTooltip } from "./Tooltip";
+
+import "./App.scss";
+
 const assert = require("assert");
 let fetchInProgress = false;
 let nextFetch = undefined;
@@ -416,6 +419,30 @@ function useToggle(initial = false) {
     return [toggled, toggleLink];
 }
 
+function usePersistentToggle(storageKey = null, initial = false) {
+    const blah = localStorage.getItem(storageKey)
+        ? localStorage.getItem(storageKey) === "true"
+        : initial;
+
+    const [toggled, setToggled] = useState(blah);
+
+    const toggleLink = (
+        <SLink
+            className="ToggleLink"
+            onClick={() =>
+                setToggled((toggled) => {
+                    localStorage.setItem(storageKey, !toggled);
+                    return !toggled;
+                })
+            }
+        >
+            {toggled ? "remove" : "add"}
+        </SLink>
+    );
+
+    return [toggled, toggleLink];
+}
+
 export {
     TLink,
     SLink,
@@ -436,4 +463,5 @@ export {
     HasActionIcon,
     HasToManyIcon,
     useToggle,
+    usePersistentToggle,
 };
