@@ -1,3 +1,4 @@
+import django
 import pytest
 from django.db.models import Q
 
@@ -13,10 +14,20 @@ from data_browser.orm_debug import _format_value
         (Q("bob") & Q("fred"), "Q('bob', 'fred')"),
         (Q("bob") | Q("fred"), "Q('bob') | Q('fred')"),
         (~(Q("bob") & Q("fred")), "~Q('bob', 'fred')"),
-        (~(Q("bob") | Q("fred")), "~Q(Q('bob') | Q('fred'))"),
         (~Q(bob=None), "~Q(bob=None)"),
         (~Q(~Q("bob")), "~Q(~Q('bob'))"),
     ],
 )
 def test_format_value(value, expected):
     assert _format_value(value) == expected
+
+
+def test_format_value_2():
+    value = ~(Q("bob") | Q("fred"))
+
+    if django.VERSION < (4, 2):
+        expected = "~Q(Q('bob') | Q('fred'))"
+    else:
+        expected = "~(Q('bob') | Q('fred'))"
+
+    assert _format_value(value) == expected
